/* ---------------------------------------------------------------------------*
 * file:        nessuswc.h                                                    *
 * purpose:     provide standard definitions accross cgi's                    *
 * author:      12/23/2004 Frank4DD                                           *
 * ---------------------------------------------------------------------------*/

#include <openssl/ssl.h>

/*********** adjust the URL and path to your cert directory below *************/
#define HOMELINK	"/nessuswc/"
#define STARTLINK	"/nessuswc/cgi-bin/scanlogin.cgi"

/* This number defines how many results are displayed in one page when    *
 * scanresults.cgi is called. A number between 10 and 25 is a good choice */
#define MAXRESDISPLAY	10

#define CIPHER_LIST "EDH-RSA-DES-CBC3-SHA:EDH-DSS-DES-CBC3-SHA:DES-CBC3-SHA:DES-CBC3-MD5:DHE-DSS-RC4-SHA:IDEA-CBC-SHA:RC4-SHA:RC4-MD5:IDEA-CBC-MD5:RC2-CBC-MD5:RC4-MD5"

#define NESSUSD_IP "127.0.0.1"
#define NESSUSD_PORT 1241

/* MAXDATASIZE should be large enough to handle a huge plugin *
 * description so we get a newline. If it is to small, we get *
 * chunks with no newline counted and its just a mess.        */
#define MAXDATASIZE 16384

/* MAXPLUGS  should be large enough to handle all plugins   *
 * we could get from the nessus daemon. If it is to small,  *
 * not all plugins can be processed. the current number is  *
 * around 5.5k. Same goes for MAXPREFS and MAXRULES,        *
 * although their numbers are much smaller (165, 0).        */
#define MAXPLUGS 10000
#define MAXCATGY 500
#define MAXFAMLY 500
#define MAXPREFS 512
#define MAXRULES 512

/* we assume that theoretically each plugin could report a hole */
#define MAXRESULTS MAXPLUGS

#define USERPROMPT "User : "
#define PASSPROMPT "Password : "
#define USERNAME "guest"
/* Although we authenticate with a client certificate, the NTP protocol  *
 * still requires a password string, but its a dummy string of any value */
#define PASSWORD "*****"
#define RESULTS_DIR "../results"
#define CA_CERT_DIR "../etc"
#define CA_CERT "cacert.pem"
#define CLIENT_CERT_DIR "../etc"
#define CLIENT_CERT "cert_guest.pem"
#define CLIENT_PRIVKEY "../etc/key_guest.pem"
#define CLIENT_NTP_VERSION "< NTP/1.2 >"
#define SERVER_NTP_VERSION "< NTP/1.2 >"
#define CLIENT_SW_VERSION	"NessusWC v1.1 (12/23/2004)"
#define CLIENT_COPYRIGHTS	"GNU GPL, @2004 Frank4DD"
#define CONTACT_EMAIL		"support@frank4dd.com"

/* default scan target ip will be displayed in scanconfig.cgi */
#define DEFAULT_TARGET_IP	"127.0.0.1"

/***************** no changes required below this line ************************/
#define PLUGS_START "SERVER <|> PLUGIN_LIST <|>"
#define PREFS_START "SERVER <|> PREFERENCES <|>"
#define RULES_START "SERVER <|> RULES <|>"
#define STATS_START "SERVER <|> STATUS <|>"
#define ERROR_START "SERVER <|> ERROR <|>"
#define HOLES_START "SERVER <|> HOLE <|>"
#define INFOS_START "SERVER <|> INFO <|>"
#define CLIENT_CONF "CLIENT <|> PREFERENCES <|>"
#define CLIENT_ATCK "CLIENT <|> NEW_ATTACK <|>"
#define PREFS_ERROR "SERVER <|> PREFERENCES_ERRORS <|>"
#define SEND_PLUGID "plugin_set <|>"
#define SERVER_END_MARKER "<|> SERVER"
#define SERVER_BYE_MARKER "SERVER <|> BYE <|> BYE <|> SERVER"
#define CLIENT_END_MARKER " <|> CLIENT"
#define PREF_SEP_MARKER " <|> "

void pagehead(char *title, char *session, FILE *out);

#define int_error(msg)  handle_error(__FILE__, __LINE__, msg)
void handle_error(const char *file, int lineno, const char *msg);

SSL * nessus_connect(char *ip, int port, char *encr, char *cert);
void nessus_login(SSL *ssl, char *user, char *pass);
int nessus_getplugs(SSL *ssl);
void nessus_getgroups(int plugs_counter);
int nessus_getprefs(SSL *ssl);
int nessus_getrules(SSL *ssl);
void nessus_setprefs(SSL *ssl, int prefs_counter);
int nessus_setplugs(SSL *ssl);
void nessus_target(SSL *ssl, char *target_ip, char *target_mask);
int nessus_geterrs(SSL *ssl);
void nessus_getstats(SSL *ssl, char *session);
void write_hostresults(char *t_ip, char *s_ip, char *session);
char * create_session_id(char *target_ip);
void get_dns(char *ip);

typedef struct plugs Plugs;
typedef struct prefs Prefs;
typedef struct rules Rules;
typedef struct catgy Catgy;
typedef struct famly Famly;

struct plugs {
                char id[6];
                char name[255];
                char category[255];
                char author[255];
                char descr[8192];
                char summary[255];
                char family[255];
              };

struct prefs {
                char name[128];
                char value[1024];
              };

struct rules {
                char command[128];
                char network[128];
              };

/* Here is our array-of-structs */
struct plugs plugslist[MAXPLUGS];
struct prefs prefslist[MAXPREFS];
struct rules ruleslist[MAXRULES];

/* Here is our array-of-pointers to the structs */
struct plugs *plugslist_ptr[MAXPLUGS];
struct prefs *prefslist_ptr[MAXPREFS];
struct rules *ruleslist_ptr[MAXRULES];

struct catgy {
		char name[sizeof(plugslist->category)];
		struct plugs *plugs_ptr[MAXPLUGS];
		int plugscount;
                int enabled;
             };

struct catgy catgylist[MAXCATGY];

struct famly {
		char name[sizeof(plugslist->family)];
		struct plugs *plugs_ptr[MAXPLUGS];
		int plugscount;
                int enabled;
             };

struct famly famlylist[MAXFAMLY];

struct result {
                 char service[81];
                 char data[8192];
                 char plugin_id[6];

               };

struct result reslist[MAXRESULTS];

/* Here are our group counters */

int catgy_counter;
int famly_counter;
int result_counter;
char dns_name[255];

/******************************* end webcert.h ********************************/
